@@ -22,6 +22,7 @@ impl Column {
     }
 
     pub fn get_rs_type(&self) -> TokenStream {
+        #[allow(unreachable_patterns)]
         let ident: TokenStream = match self.col_type {
             ColumnType::Char(_)
             | ColumnType::String(_)
@@ -88,7 +89,7 @@ impl Column {
             ColumnType::Custom(s) => {
                 let s = s.to_string();
                 quote! { ColumnType::Custom(#s.to_owned()).def() }
-            },
+            }
             _ => unimplemented!(),
         };
         if !self.not_null {
@@ -118,33 +119,18 @@ impl From<&ColumnDef> for Column {
             Some(ty) => ty.clone(),
             None => panic!("ColumnType should not be empty"),
         };
-        let auto_increments: Vec<bool> = col_def
+        let auto_increment = col_def
             .get_column_spec()
             .iter()
-            .filter_map(|spec| match spec {
-                ColumnSpec::AutoIncrement => Some(true),
-                _ => None,
-            })
-            .collect();
-        let auto_increment = !auto_increments.is_empty();
-        let not_nulls: Vec<bool> = col_def
+            .any(|spec| matches!(spec, ColumnSpec::AutoIncrement));
+        let not_null = col_def
             .get_column_spec()
             .iter()
-            .filter_map(|spec| match spec {
-                ColumnSpec::NotNull => Some(true),
-                _ => None,
-            })
-            .collect();
-        let not_null = !not_nulls.is_empty();
-        let uniques: Vec<bool> = col_def
+            .any(|spec| matches!(spec, ColumnSpec::NotNull));
+        let unique = col_def
             .get_column_spec()
             .iter()
-            .filter_map(|spec| match spec {
-                ColumnSpec::UniqueKey => Some(true),
-                _ => None,
-            })
-            .collect();
-        let unique = !uniques.is_empty();
+            .any(|spec| matches!(spec, ColumnSpec::UniqueKey));
         Self {
             name,
             col_type,
@@ -284,7 +270,7 @@ mod tests {
 
     #[test]
     fn test_from_column_def() {
-        let column: Column = ColumnDef::new(Alias::new("id")).string().into();
+        let column: Column = ColumnDef::new(Alias::new("id")).string().to_owned().into();
         assert_eq!(
             column.get_def().to_string(),
             quote! {
@@ -293,13 +279,18 @@ mod tests {
             .to_string()
         );
 
-        let column: Column = ColumnDef::new(Alias::new("id")).string().not_null().into();
+        let column: Column = ColumnDef::new(Alias::new("id"))
+            .string()
+            .not_null()
+            .to_owned()
+            .into();
         assert!(column.not_null);
 
         let column: Column = ColumnDef::new(Alias::new("id"))
             .string()
             .unique_key()
             .not_null()
+            .to_owned()
             .into();
         assert!(column.unique);
         assert!(column.not_null);
@@ -309,6 +300,7 @@ mod tests {
             .auto_increment()
             .unique_key()
             .not_null()
+            .to_owned()
             .into();
         assert!(column.auto_increment);
         assert!(column.unique);
